@@ -11,10 +11,10 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "mem.h"
 #include "dump.h"
 #include "encode.h"
 #include "intern.h"
+#include "mem.h"
 #include "odd.h"
 #include "parse.h"
 #include "rails.h"
@@ -22,7 +22,7 @@
 typedef struct _yesNoOpt {
     VALUE sym;
     char *attr;
-} * YesNoOpt;
+} *YesNoOpt;
 
 void Init_oj();
 
@@ -135,6 +135,7 @@ static VALUE newline_sym;
 static VALUE nilnil_sym;
 static VALUE null_sym;
 static VALUE object_sym;
+static VALUE omit_null_byte_sym;
 static VALUE omit_nil_sym;
 static VALUE rails_sym;
 static VALUE raise_sym;
@@ -156,8 +157,8 @@ static VALUE word_sym;
 static VALUE xmlschema_sym;
 static VALUE xss_safe_sym;
 
-rb_encoding *oj_utf8_encoding = 0;
-int oj_utf8_encoding_index = 0;
+rb_encoding *oj_utf8_encoding       = 0;
+int          oj_utf8_encoding_index = 0;
 
 #ifdef HAVE_PTHREAD_MUTEX_INIT
 pthread_mutex_t oj_cache_mutex;
@@ -222,6 +223,7 @@ struct _options oj_default_options = {
         0,          // array_size
         AutoNan,    // nan_dump
         false,      // omit_nil
+        false,      // omit_null_byte
         MAX_DEPTH,  // max_depth
     },
     {
@@ -291,6 +293,7 @@ struct _options oj_default_options = {
  *used
  * - *:array_class* [_Class_|_nil_] Class to use instead of Array on load
  * - *:omit_nil* [_true_|_false_] if true Hash and Object attributes with nil values are omitted
+ * - *:omit_null_byte* [_true_|_false_] if true null bytes in strings will be omitted when dumping
  * - *:ignore* [_nil_|_Array_] either nil or an Array of classes to ignore when dumping
  * - *:ignore_under* [_Boolean_] if true then attributes that start with _ are ignored when dumping in
  *object or custom mode.
@@ -384,6 +387,7 @@ static VALUE get_def_opts(VALUE self) {
         opts,
         cache_keys_sym,
         (Yes == oj_default_options.cache_keys) ? Qtrue : ((No == oj_default_options.cache_keys) ? Qfalse : Qnil));
+
     switch (oj_default_options.mode) {
     case StrictMode: rb_hash_aset(opts, mode_sym, strict_sym); break;
     case CompatMode: rb_hash_aset(opts, mode_sym, compat_sym); break;
@@ -459,13 +463,14 @@ static VALUE get_def_opts(VALUE self) {
     default: rb_hash_aset(opts, nan_sym, auto_sym); break;
     }
     rb_hash_aset(opts, omit_nil_sym, oj_default_options.dump_opts.omit_nil ? Qtrue : Qfalse);
+    rb_hash_aset(opts, omit_null_byte_sym, oj_default_options.dump_opts.omit_null_byte ? Qtrue : Qfalse);
     rb_hash_aset(opts, oj_hash_class_sym, oj_default_options.hash_class);
     rb_hash_aset(opts, oj_array_class_sym, oj_default_options.array_class);
 
     if (NULL == oj_default_options.ignore) {
         rb_hash_aset(opts, ignore_sym, Qnil);
     } else {
-        VALUE *        vp;
+        VALUE         *vp;
         volatile VALUE a = rb_ary_new();
 
         for (vp = oj_default_options.ignore; Qnil != *vp; vp++) {
@@ -640,15 +645,9 @@ static int parse_options_cb(VALUE k, VALUE v, VALUE opts) {
     } else if (float_prec_sym == k) {
         int n;
 
-#ifdef RUBY_INTEGER_UNIFICATION
         if (rb_cInteger != rb_obj_class(v)) {
             rb_raise(rb_eArgError, ":float_precision must be a Integer.");
         }
-#else
-        if (T_FIXNUM != rb_type(v)) {
-            rb_raise(rb_eArgError, ":float_precision must be a Fixnum.");
-        }
-#endif
         n = FIX2INT(v);
         if (0 >= n) {
             *copts->float_fmt = '\0';
@@ -663,15 +662,9 @@ static int parse_options_cb(VALUE k, VALUE v, VALUE opts) {
     } else if (cache_str_sym == k || cache_string_sym == k) {
         int n;
 
-#ifdef RUBY_INTEGER_UNIFICATION
         if (rb_cInteger != rb_obj_class(v)) {
             rb_raise(rb_eArgError, ":cache_str must be a Integer.");
         }
-#else
-        if (T_FIXNUM != rb_type(v)) {
-            rb_raise(rb_eArgError, ":cache_str must be a Fixnum.");
-        }
-#endif
         n = FIX2INT(v);
         if (0 >= n) {
             copts->cache_str = 0;
@@ -684,15 +677,9 @@ static int parse_options_cb(VALUE k, VALUE v, VALUE opts) {
     } else if (sec_prec_sym == k) {
         int n;
 
-#ifdef RUBY_INTEGER_UNIFICATION
         if (rb_cInteger != rb_obj_class(v)) {
             rb_raise(rb_eArgError, ":second_precision must be a Integer.");
         }
-#else
-        if (T_FIXNUM != rb_type(v)) {
-            rb_raise(rb_eArgError, ":second_precision must be a Fixnum.");
-        }
-#endif
         n = NUM2INT(v);
         if (0 > n) {
             n                   = 0;
@@ -883,6 +870,17 @@ static int parse_options_cb(VALUE k, VALUE v, VALUE opts) {
         } else {
             rb_raise(rb_eArgError, ":omit_nil must be true or false.");
         }
+    } else if (omit_null_byte_sym == k) {
+        if (Qnil == v) {
+            return ST_CONTINUE;
+        }
+        if (Qtrue == v) {
+            copts->dump_opts.omit_null_byte = true;
+        } else if (Qfalse == v) {
+            copts->dump_opts.omit_null_byte = false;
+        } else {
+            rb_raise(rb_eArgError, ":omit_null_byte must be true or false.");
+        }
     } else if (oj_ascii_only_sym == k) {
         // This is here only for backwards compatibility with the original Oj.
         if (Qtrue == v) {
@@ -950,7 +948,7 @@ static int parse_options_cb(VALUE k, VALUE v, VALUE opts) {
         if (Qnil == v) {
             return ST_CONTINUE;
         }
-	copts->sym_key = (Qtrue == v) ? Yes : No;
+        copts->sym_key = (Qtrue == v) ? Yes : No;
     }
     return ST_CONTINUE;
 }
@@ -1115,7 +1113,7 @@ static VALUE load(int argc, VALUE *argv, VALUE self) {
  * Returns [_Object_|_Hash_|_Array_|_String_|_Fixnum_|_Float_|_Boolean_|_nil_]
  */
 static VALUE load_file(int argc, VALUE *argv, VALUE self) {
-    char *            path;
+    char             *path;
     int               fd;
     Mode              mode = oj_default_options.mode;
     struct _parseInfo pi;
@@ -1123,7 +1121,7 @@ static VALUE load_file(int argc, VALUE *argv, VALUE self) {
     if (1 > argc) {
         rb_raise(rb_eArgError, "Wrong number of arguments to load().");
     }
-    Check_Type(*argv, T_STRING);
+    path = StringValuePtr(*argv);
     parse_info_init(&pi);
     pi.options   = oj_default_options;
     pi.handler   = Qnil;
@@ -1154,16 +1152,15 @@ static VALUE load_file(int argc, VALUE *argv, VALUE self) {
             }
         }
     }
-    path = StringValuePtr(*argv);
 #ifdef _WIN32
     {
         WCHAR *wide_path;
         wide_path = rb_w32_mbstr_to_wstr(CP_UTF8, path, -1, NULL);
-        fd = rb_w32_wopen(wide_path, O_RDONLY);
+        fd        = rb_w32_wopen(wide_path, O_RDONLY);
         OJ_FREE(wide_path);
     }
 #else
-    fd = open(path, O_RDONLY);
+    fd             = open(path, O_RDONLY);
 #endif
     if (0 == fd) {
         rb_raise(rb_eIOError, "%s", strerror(errno));
@@ -1238,10 +1235,10 @@ static VALUE safe_load(VALUE self, VALUE doc) {
  */
 
 struct dump_arg {
-    struct _out *    out;
+    struct _out     *out;
     struct _options *copts;
     int              argc;
-    VALUE *          argv;
+    VALUE           *argv;
 };
 
 static VALUE dump_body(VALUE a) {
@@ -1297,8 +1294,9 @@ static VALUE dump(int argc, VALUE *argv, VALUE self) {
 
     oj_out_init(arg.out);
 
-    arg.out->omit_nil  = copts.dump_opts.omit_nil;
-    arg.out->caller    = CALLER_DUMP;
+    arg.out->omit_nil = copts.dump_opts.omit_nil;
+    arg.out->omit_null_byte = copts.dump_opts.omit_null_byte;
+    arg.out->caller   = CALLER_DUMP;
 
     return rb_ensure(dump_body, (VALUE)&arg, dump_ensure, (VALUE)&arg);
 }
@@ -1345,7 +1343,8 @@ static VALUE to_json(int argc, VALUE *argv, VALUE self) {
 
     oj_out_init(&out);
 
-    out.omit_nil  = copts.dump_opts.omit_nil;
+    out.omit_nil = copts.dump_opts.omit_nil;
+    out.omit_null_byte = copts.dump_opts.omit_null_byte;
     // For obj.to_json or generate nan is not allowed but if called from dump
     // it is.
     oj_dump_obj_to_json_using_params(*argv, &copts, &out, argc - 1, argv + 1);
@@ -1377,7 +1376,6 @@ static VALUE to_file(int argc, VALUE *argv, VALUE self) {
     if (3 == argc) {
         oj_parse_options(argv[2], &copts);
     }
-    Check_Type(*argv, T_STRING);
     oj_write_obj_to_file(argv[1], StringValuePtr(*argv), &copts);
 
     return Qnil;
@@ -1719,8 +1717,7 @@ static VALUE protect_require(VALUE x) {
 
 extern void print_all_odds(const char *label);
 
-static VALUE
-debug_odd(VALUE self, VALUE label) {
+static VALUE debug_odd(VALUE self, VALUE label) {
     print_all_odds(RSTRING_PTR(label));
     return Qnil;
 }
@@ -1780,7 +1777,7 @@ void Init_oj(void) {
     rb_protect(protect_require, Qnil, &err);
     rb_require("stringio");
     oj_utf8_encoding_index = rb_enc_find_index("UTF-8");
-    oj_utf8_encoding = rb_enc_from_index(oj_utf8_encoding_index);
+    oj_utf8_encoding       = rb_enc_from_index(oj_utf8_encoding_index);
 
     // rb_define_module_function(Oj, "hash_test", hash_test, 0);
     rb_define_module_function(Oj, "debug_odd", debug_odd, 1);
@@ -1819,49 +1816,49 @@ void Init_oj(void) {
 
     rb_define_module_function(Oj, "mem_report", mem_report, 0);
 
-    oj_add_value_id          = rb_intern("add_value");
-    oj_array_append_id       = rb_intern("array_append");
-    oj_array_end_id          = rb_intern("array_end");
-    oj_array_start_id        = rb_intern("array_start");
-    oj_as_json_id            = rb_intern("as_json");
-    oj_at_id                 = rb_intern("at");
-    oj_begin_id              = rb_intern("begin");
-    oj_bigdecimal_id         = rb_intern("BigDecimal");
-    oj_end_id                = rb_intern("end");
-    oj_error_id              = rb_intern("error");
-    oj_exclude_end_id        = rb_intern("exclude_end?");
-    oj_file_id               = rb_intern("file?");
-    oj_fileno_id             = rb_intern("fileno");
-    oj_ftype_id              = rb_intern("ftype");
-    oj_hash_end_id           = rb_intern("hash_end");
-    oj_hash_key_id           = rb_intern("hash_key");
-    oj_hash_set_id           = rb_intern("hash_set");
-    oj_hash_start_id         = rb_intern("hash_start");
-    oj_iconv_id              = rb_intern("iconv");
-    oj_json_create_id        = rb_intern("json_create");
-    oj_length_id             = rb_intern("length");
-    oj_new_id                = rb_intern("new");
-    oj_parse_id              = rb_intern("parse");
-    oj_pos_id                = rb_intern("pos");
-    oj_raw_json_id           = rb_intern("raw_json");
-    oj_read_id               = rb_intern("read");
-    oj_readpartial_id        = rb_intern("readpartial");
-    oj_replace_id            = rb_intern("replace");
-    oj_stat_id               = rb_intern("stat");
-    oj_string_id             = rb_intern("string");
-    oj_to_h_id               = rb_intern("to_h");
-    oj_to_hash_id            = rb_intern("to_hash");
-    oj_to_json_id            = rb_intern("to_json");
-    oj_to_s_id               = rb_intern("to_s");
-    oj_to_sym_id             = rb_intern("to_sym");
-    oj_to_time_id            = rb_intern("to_time");
-    oj_tv_nsec_id            = rb_intern("tv_nsec");
-    oj_tv_sec_id             = rb_intern("tv_sec");
-    oj_tv_usec_id            = rb_intern("tv_usec");
-    oj_utc_id                = rb_intern("utc");
-    oj_utc_offset_id         = rb_intern("utc_offset");
-    oj_utcq_id               = rb_intern("utc?");
-    oj_write_id              = rb_intern("write");
+    oj_add_value_id    = rb_intern("add_value");
+    oj_array_append_id = rb_intern("array_append");
+    oj_array_end_id    = rb_intern("array_end");
+    oj_array_start_id  = rb_intern("array_start");
+    oj_as_json_id      = rb_intern("as_json");
+    oj_at_id           = rb_intern("at");
+    oj_begin_id        = rb_intern("begin");
+    oj_bigdecimal_id   = rb_intern("BigDecimal");
+    oj_end_id          = rb_intern("end");
+    oj_error_id        = rb_intern("error");
+    oj_exclude_end_id  = rb_intern("exclude_end?");
+    oj_file_id         = rb_intern("file?");
+    oj_fileno_id       = rb_intern("fileno");
+    oj_ftype_id        = rb_intern("ftype");
+    oj_hash_end_id     = rb_intern("hash_end");
+    oj_hash_key_id     = rb_intern("hash_key");
+    oj_hash_set_id     = rb_intern("hash_set");
+    oj_hash_start_id   = rb_intern("hash_start");
+    oj_iconv_id        = rb_intern("iconv");
+    oj_json_create_id  = rb_intern("json_create");
+    oj_length_id       = rb_intern("length");
+    oj_new_id          = rb_intern("new");
+    oj_parse_id        = rb_intern("parse");
+    oj_pos_id          = rb_intern("pos");
+    oj_raw_json_id     = rb_intern("raw_json");
+    oj_read_id         = rb_intern("read");
+    oj_readpartial_id  = rb_intern("readpartial");
+    oj_replace_id      = rb_intern("replace");
+    oj_stat_id         = rb_intern("stat");
+    oj_string_id       = rb_intern("string");
+    oj_to_h_id         = rb_intern("to_h");
+    oj_to_hash_id      = rb_intern("to_hash");
+    oj_to_json_id      = rb_intern("to_json");
+    oj_to_s_id         = rb_intern("to_s");
+    oj_to_sym_id       = rb_intern("to_sym");
+    oj_to_time_id      = rb_intern("to_time");
+    oj_tv_nsec_id      = rb_intern("tv_nsec");
+    oj_tv_sec_id       = rb_intern("tv_sec");
+    oj_tv_usec_id      = rb_intern("tv_usec");
+    oj_utc_id          = rb_intern("utc");
+    oj_utc_offset_id   = rb_intern("utc_offset");
+    oj_utcq_id         = rb_intern("utc?");
+    oj_write_id        = rb_intern("write");
 
     rb_require("oj/bag");
     rb_require("oj/error");
@@ -1988,6 +1985,8 @@ void Init_oj(void) {
     rb_gc_register_address(&oj_quirks_mode_sym);
     oj_safe_sym = ID2SYM(rb_intern("safe"));
     rb_gc_register_address(&oj_safe_sym);
+    omit_null_byte_sym = ID2SYM(rb_intern("omit_null_byte"));
+    rb_gc_register_address(&omit_null_byte_sym);
     oj_space_before_sym = ID2SYM(rb_intern("space_before"));
     rb_gc_register_address(&oj_space_before_sym);
     oj_space_sym = ID2SYM(rb_intern("space"));
