@@ -1,9 +1,9 @@
 // Copyright (c) 2012, 2017 Peter Ohler. All rights reserved.
 // Licensed under the MIT License. See LICENSE file in the project root for license details.
 
-#include "mem.h"
 #include "dump.h"
 #include "encode.h"
+#include "mem.h"
 
 extern VALUE Oj;
 
@@ -56,10 +56,10 @@ void oj_str_writer_init(StrWriter sw, int buf_size) {
     }
     // Must be allocated. Using the out.stack_buffer results in double frees
     // and I haven't figured out why yet.
-    sw->out.buf        = OJ_R_ALLOC_N(char, buf_size);
-    sw->out.cur        = sw->out.buf;
-    sw->out.end        = sw->out.buf + buf_size - BUFFER_EXTRA;
-    sw->out.allocated  = true;
+    sw->out.buf       = OJ_R_ALLOC_N(char, buf_size);
+    sw->out.cur       = sw->out.buf;
+    sw->out.end       = sw->out.buf + buf_size - BUFFER_EXTRA;
+    sw->out.allocated = true;
 
     *sw->out.cur       = '\0';
     sw->out.circ_cache = NULL;
@@ -281,7 +281,6 @@ static VALUE str_writer_new(int argc, VALUE *argv, VALUE self) {
 static VALUE str_writer_push_key(VALUE self, VALUE key) {
     StrWriter sw = (StrWriter)DATA_PTR(self);
 
-    rb_check_type(key, T_STRING);
     oj_str_writer_push_key(sw, StringValuePtr(key));
 
     return Qnil;
@@ -303,7 +302,6 @@ static VALUE str_writer_push_object(int argc, VALUE *argv, VALUE self) {
         if (Qnil == argv[0]) {
             oj_str_writer_push_object(sw, 0);
         } else {
-            rb_check_type(argv[0], T_STRING);
             oj_str_writer_push_object(sw, StringValuePtr(argv[0]));
         }
         break;
@@ -332,7 +330,6 @@ static VALUE str_writer_push_array(int argc, VALUE *argv, VALUE self) {
         if (Qnil == argv[0]) {
             oj_str_writer_push_array(sw, 0);
         } else {
-            rb_check_type(argv[0], T_STRING);
             oj_str_writer_push_array(sw, StringValuePtr(argv[0]));
         }
         break;
@@ -359,7 +356,6 @@ static VALUE str_writer_push_value(int argc, VALUE *argv, VALUE self) {
         if (Qnil == argv[1]) {
             oj_str_writer_push_value((StrWriter)DATA_PTR(self), *argv, 0);
         } else {
-            rb_check_type(argv[1], T_STRING);
             oj_str_writer_push_value((StrWriter)DATA_PTR(self), *argv, StringValuePtr(argv[1]));
         }
         break;
@@ -378,17 +374,13 @@ static VALUE str_writer_push_value(int argc, VALUE *argv, VALUE self) {
  * - *key* [_String_] the key if adding to an object in the JSON document
  */
 static VALUE str_writer_push_json(int argc, VALUE *argv, VALUE self) {
-    rb_check_type(argv[0], T_STRING);
     switch (argc) {
     case 1: oj_str_writer_push_json((StrWriter)DATA_PTR(self), StringValuePtr(*argv), 0); break;
     case 2:
         if (Qnil == argv[1]) {
             oj_str_writer_push_json((StrWriter)DATA_PTR(self), StringValuePtr(*argv), 0);
         } else {
-            rb_check_type(argv[1], T_STRING);
-            oj_str_writer_push_json((StrWriter)DATA_PTR(self),
-                                    StringValuePtr(*argv),
-                                    StringValuePtr(argv[1]));
+            oj_str_writer_push_json((StrWriter)DATA_PTR(self), StringValuePtr(*argv), StringValuePtr(argv[1]));
         }
         break;
     default: rb_raise(rb_eArgError, "Wrong number of argument to 'push_json'."); break;
