@@ -29,7 +29,7 @@ class JSONCommonInterfaceTest < Test::Unit::TestCase
     #@json = '{"a":2,"b":5.23683071,"c":"c","d":[1,"b",3.14],"e":{"foo":"bar"},'\
     #'"g":"\\"\\u0000\\u001f","h":1000.0,"i":0.001}'
     @json = '{"a":2,"c":"c","d":[1,"b",3.14],"e":{"foo":"bar"},'\
-	    '"g":"\\"\\u0000\\u001f","h":1000.0,"i":0.001}'
+            '"g":"\\"\\u0000\\u001f","h":1000.0,"i":0.001}'
   end
 
   def test_index
@@ -43,15 +43,15 @@ class JSONCommonInterfaceTest < Test::Unit::TestCase
   # functionality and perform better.
 
   def test_parser
-    assert_match /::Parser\z/, JSON.parser.name
+    assert_match(/::Parser\z/, JSON.parser.name)
   end
 
   def test_generator
-    assert_match /::Generator\z/, JSON.generator.name
+    assert_match(/::Generator\z/, JSON.generator.name)
   end
 
   def test_state
-    assert_match /::Generator::State\z/, JSON.state.name
+    assert_match(/::Generator::State\z/, JSON.state.name)
   end
 
   # This doesn't have anything to do with JSON parsing or generation. It seems
